@@ -6,7 +6,7 @@ from typing import Optional
 import requests
 
 # IMPORTATION INTERNAL
-import degiro_connector.core.constants.urls as urls
+from degiro_connector.core.constants import urls
 from degiro_connector.core.abstracts.abstract_action import AbstractAction
 from degiro_connector.trading.models.trading_pb2 import (
     Credentials,
@@ -42,7 +42,7 @@ class ActionDeleteOrder(AbstractAction):
         response_raw = None
 
         try:
-            response_raw = session.send(prepped, verify=False)
+            response_raw = session.send(prepped)
             response_raw.raise_for_status()
         except requests.HTTPError as e:
             status_code = getattr(response_raw, "status_code", "No status_code found.")
