@@ -7,7 +7,7 @@ from typing import Union
 import requests
 
 # IMPORTATION INTERNAL
-import degiro_connector.core.constants.urls as urls
+from degiro_connector.core.constants import urls
 from degiro_connector.core.abstracts.abstract_action import AbstractAction
 from degiro_connector.trading.models.trading_pb2 import (
     Credentials,
@@ -68,7 +68,7 @@ class ActionGetCashAccountReport(AbstractAction):
                         month=10,
                         day=15,
                     )
-                    from_date = CashAccountReport.Request.Date(
+                    to_date = CashAccountReport.Request.Date(
                         year=2020,
                         month=10,
                         day=16,
@@ -115,7 +115,7 @@ class ActionGetCashAccountReport(AbstractAction):
         response_raw = None
 
         try:
-            response_raw = session.send(prepped, verify=False)
+            response_raw = session.send(prepped)
             response_raw.raise_for_status()
             response_text = response_raw.text
 
